@@ -14,7 +14,6 @@ __email__ = "tpovedatd@gmail.com"
 
 import os
 
-import artellapipe
 from artellapipe.core import project as artella_project
 
 
@@ -25,19 +24,6 @@ class PlotTwist(artella_project.ArtellaProject, object):
     def init(self, force_skip_hello=False):
         super(PlotTwist, self).init(force_skip_hello=force_skip_hello)
 
-        self.create_ocio_manager()
-
-    def create_ocio_manager(self):
-        """
-        Creates instance of the OCIO Mnaager used by the project
-        :return: ArtellaOCIOManager
-        """
-
-        ocio_manager = artellapipe.OCIOMgr()
-        ocio_manager.set_project(self)
-
-        return ocio_manager
-
     def get_toolsets_paths(self):
         """
         Overrides base ArtellaProject get_toolsets_paths
